IErr<Value> class

Implemented types

Constructors

IErr(IError error)
const
IErr.from(IErrorType type)
factory

Properties

error IError
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator /(dynamic a) Error
Returns the error if it is CErr or throws an error if it is COk Convinient operator to get the error from the result, user should ensure that the result is CErr, otherwise it will throw an UnimplementedError Usage:
override
operator ==(Object other) bool
The equality operator.
inherited
operator |(dynamic _) → Value
Returns the value if it is COk or throws an error if it is CErr Convinient operator to get the value from the result, user should ensure that the result is COk, otherwise it will throw an UnimplementedError Usage:
override
operator ~() Error
Returns the value if it is IOk or error if it is IErr Convinient operator to get the inner value from the result, Usage:
override