IResult<Value> class sealed

A result type that can be either a value or a error that implements IError.

Implementers

Constructors

IResult.err(IError error)
factory
IResult.from(dynamic value)
Constructs a IResult from a dynamic value If the value is IResult it will return the value itself If the value is Value it will return IOk otherwise returns IErr Usage:
factory
IResult.ok(Value value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator /(dynamic a) Error
Returns the error if it is CErr or throws an error if it is COk Convinient operator to get the error from the result, user should ensure that the result is CErr, otherwise it will throw an UnimplementedError Usage:
operator ==(Object other) bool
The equality operator.
inherited
operator |(dynamic a) → Value
Returns the value if it is COk or throws an error if it is CErr Convinient operator to get the value from the result, user should ensure that the result is COk, otherwise it will throw an UnimplementedError Usage:
operator ~() → dynamic
Returns the value if it is IOk or error if it is IErr Convinient operator to get the inner value from the result, Usage: