operator | method
Returns the Value if it is Some or throws an error if it is None
Convinient operator to get the value from the result,
user should ensure that the result is Some, otherwise it will throw an UnimplementedError
Usage:
final res = Option
Implementation
@override
T operator |(_) => throw UnimplementedError();