operator / method
Returns None or throws an error if it is Some Convinient operator to get the error from the result, user should ensure that the value is None, otherwise it will throw an UnimplementedError Usage: final res = Option.none(); final err = res / 0; assert(err is None);
Implementation
@override
operator /(a) => 1;