operator ~ method

dynamic operator ~()

Returns the inner Value from Some or None Convinient operator to get the inner value from the Option, Usage: final res = Option

final res = Option

Implementation

operator ~() => ~this;