operator | method

Value operator |(
  1. dynamic a
)

Returns the value if it is TOk or throws an error if it is TErr Convinient operator to get the value from the result, user should ensure that the result is TOk, otherwise it will throw an UnimplementedError Usage: final res = TResult

Implementation

Value operator |(a) => this | a;