Returns the error if it is CErr or throws an error if it is COk
Convinient operator to get the error from the result,
user should ensure that the result is CErr, otherwise it will throw an UnimplementedError
Usage:
final res = TResult
Returns the value if it is TOk or throws an error if it is TErr
Convinient operator to get the value from the result,
user should ensure that the result is TOk, otherwise it will throw an UnimplementedError
Usage:
final res = TResult